@@ -18,7 +18,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-
 import json
 import optparse
 import os
@@ -125,12 +124,6 @@ def init_corenlp_command(corenlp_path, memory, properties):
 
     return "%s %s -cp %s %s %s" % (java_path, limit, ':'.join(jars), classname, props)
 
-
-def remove_id(word):
-    """Removes the numeric suffix from the parsed recognized words: e.g. 'word-2' > 'word' """
-    return word.replace("'", "")
-
-
 def parse_bracketed(s):
     '''Parse word features [abc=... def = ...]
     Also manages to parse out features that have XML within them
@@ -193,7 +186,7 @@ def parse_parser_results(text):
             else:
                 split_entry = re.split("\(|, |-", line[:-1])
                 if len(split_entry) == 5:
-                    rel, left, leftindex, right, rightindex = map(lambda x: remove_id(x), split_entry)
+                    rel, left, leftindex, right, rightindex = split_entry
                     sentence['dependencies'].append(tuple([rel, left, leftindex, right, rightindex]))
 
         elif state == STATE_COREFERENCE:
@@ -500,3 +493,4 @@ if __name__ == '__main__':
     except KeyboardInterrupt:
         print >>sys.stderr, "Bye."
         exit()
+
